@@ -3,8 +3,7 @@ from dataverk.dataverk import Dataverk
 from dataverk.dataverk import Dataverk as Client
 from dataverk.datapackage import Datapackage
 
-__all__ = ['connectors',
-           'utils',
+__all__ = ['utils',
            'Datapackage',
            'Client',
            'Dataverk'
